# [Meronex Icons](https://icons.meronex.com/) (react-icons fork)

[![npm][npm-image]][npm-url]

[npm-image]: https://img.shields.io/npm/v/react-icons.svg?style=flat-square
[npm-url]: https://www.npmjs.com/package/react-icons

Include popular icons in your React projects easily with `react-icons`, which utilizes ES6 imports that allows you to include only the icons that your project is using.

## Credits & Motivation for the fork

This is a fork of [react-icons](https://github.com/react-icons/react-icons) and was created specifically to resolve issue the bundling issue [#154, see here](https://github.com/react-icons/react-icons/issues/154).

It was meant to be used temporary until the changes are merged upstream however due to the lack of activity in react-icons, I have decided to put it publicly due to the inactivity. 

#### Why did you change the logo/theme of the preview site? 

Again,this was meant for internal consumption, the bundle issue was show stopper for us. I shared it because I thought it might 
help others, I hope those changes gets merged upstream. 

#### What else did you change?

I've merged some open pull requests, added icons and fixed some performance issue with the preview site, more specifically:

- Added Icon Sets
    - flag-icon-css
    - IcoMoon Free
    - Simple Icons
    - Logos
    - VS Code Icons
    - Remix Icons fill
    - Heroicons
    - BoxIcons
    
- Merged open PRs 
    - Remove pId attribute from AI icons [#310](https://github.com/react-icons/react-ic)
    - Add support for stroke-based icons [#284](https://github.com/react-icons/react-icons/pull/284)
    
- Improved Preview Site
    - Show the icon set next to the titles
    - Improve search performance by caching results
    - Copy the entire absolute URL so it can be easily inserted
 
#### Do you plan to keep maintaining it?

I'd rather have the changes merged upstream, but I will keep this maintained if saves others time and effort and the main 
react-icons remains in active. 

   
## Installation

### Yarn
```bash
yarn add @meronex/icons
```

### NPM
```bash
npm install @meronex/icons --save
```

## Usage

```jsx
import  FaBeer from '@meronex/icons/FaBeer';

class Question extends React.Component {
    render() {
        return <h3> Lets go for a <FaBeer />? </h3>
    }
}
```

[View the documentation](https://icons.meronex.com/) for further usage examples and how to use icons from other packages. *NOTE*: each Icon package has it's own subfolder under `@meronex/icons` you import from.

For example, to use an icon from **Material Design**, your import would be: `import  ICON_NAME  from 'react-icons/md/ICON_NAME';`

## Icons

Icon Library|License|Version
---|---|---
[Font Awesome](https://fontawesome.com/)|[CC BY 4.0 License](https://creativecommons.org/licenses/by/4.0/)|5.12.1
[Ionicons](https://ionicons.com/)|[MIT](https://github.com/ionic-team/ionicons/blob/master/LICENSE)|4.5.6
[Material Design icons](http://google.github.io/material-design-icons/)|[Apache License Version 2.0](https://github.com/google/material-design-icons/blob/master/LICENSE)|3.0.1
[Material Design Community icons](https://github.com/templarian/MaterialDesign)|[SIL](https://github.com/google/material-design-icons/blob/master/LICENSE)|52442e9e6ea4424c41fb6489911c6f87fe83a7a8
[Typicons](http://s-ings.com/typicons/)|[CC BY-SA 3.0](https://creativecommons.org/licenses/by-sa/3.0/)|2.0.9
[Github Octicons icons](https://octicons.github.com/)|[MIT](https://github.com/primer/octicons/blob/master/LICENSE)|8.5.0
[Feather](https://feathericons.com/)|[MIT](https://github.com/feathericons/feather/blob/master/LICENSE)|4.21.0
[Game Icons](https://game-icons.net/)|[CC BY 3.0](https://creativecommons.org/licenses/by/3.0/)|a53463d41d4f055fa71097ae74da4c508c9bb09d
[Weather Icons](https://erikflowers.github.io/weather-icons/)|[SIL OFL 1.1](http://scripts.sil.org/OFL)|2.0.10
[Devicons](https://vorillaz.github.io/devicons/)|[MIT](https://opensource.org/licenses/MIT)|1.8.0
[Ant Design Icons](https://github.com/ant-design/ant-design-icons)|[MIT](https://opensource.org/licenses/MIT)|4.0.0
[Bootstrap Icons](https://github.com/twbs/icons)|[MIT](https://opensource.org/licenses/MIT)|1.0.0-alpha3
[Remix Icon](https://github.com/Remix-Design/RemixIcon)|[Apache License Version 2.0](http://www.apache.org/licenses/)|2.3.0
[Flat Color Icons](https://github.com/icons8/flat-color-icons)|[MIT](https://opensource.org/licenses/MIT)|1.0.2
[Grommet-Icons](https://github.com/grommet/grommet-icons)|[Apache License Version 2.0](http://www.apache.org/licenses/)|4.4.0
[css.gg](https://github.com/astrit/css.gg)|[MIT](https://opensource.org/licenses/MIT)|2.0.0
[IcoMoon Free](https://github.com/Keyamoon/IcoMoon-Free)|[CC BY 4.0 License](https://creativecommons.org/licenses/by/4.0/)|1.0.0
[BoxIcons](https://github.com/atisawd/boxicons)|[CC BY 4.0 License](https://creativecommons.org/licenses/by/4.0/)|2.0.5
[VS Code Icons](https://github.com/microsoft/vscode-codicons)|[CC BY 4.0](https://creativecommons.org/licenses/by/4.0/)|0.0.1
[flag-icon-css](https://github.com/lipis/flag-icon-css)|[MIT License](https://github.com/lipis/flag-icon-css/blob/master/LICENSE)|3.5.0
[Logos](https://github.com/gilbarbara/logos)|[CC0 1.0 Universal](https://github.com/gilbarbara/logos/blob/master/LICENSE.txt)|2018.01
[Simple Icons](https://simpleicons.org/)|[CC0 1.0 Universal](https://creativecommons.org/publicdomain/zero/1.0/)| 1.17.1-998-gd4b07ad4
[Heroicons](https://github.com/refactoringui/heroicons)|[MIT](https://opensource.org/licenses/MIT)| v0.3.7

## Configuration

You can configure react-icons props using [React Context API](https://reactjs.org/docs/context.html).

_Requires **React 16.3** or higher._

```jsx
import { IconContext } from "@meronex/icons";

<IconContext.Provider value={{ color: "blue", className: "global-class-name" }}>
  <div>
    <FaFolder />
  </div>
</IconContext.Provider>
```

| Key         | Default               | Notes                           |
| ----------- | --------------------- | ------------------------------- |
| `color`     | `undefined` (inherit) |                                 |
| `size`      | `1em`                 |                                 |
| `className` | `undefined`           |                                 |
| `style`     | `undefined`           | Can overwrite size and color    |
| `attr`      | `undefined`           | Overwritten by other attributes |
| `title`     | `undefined`           | Icon description for accessibility |


### Adjustment CSS

From version 3, `vertical-align: middle` is not automatically given. Please use IconContext to specify className or specify an inline style.

#### Global Inline Styling

```tsx
<IconContext.Provider value={{ style: { verticalAlign: 'middle' } }}>
```

#### Global `className` Styling

Component

```tsx
<IconContext.Provider value={{ className: 'react-icons' }}>
```

CSS

```css
.react-icons {
  vertical-align: middle;
}
```

### TypeScript native support

Dependencies on `@types/@meronex/icons` can be deleted.

#### Yarn
```bash
yarn remove @types/@meronex/icons
```

#### NPM
```bash
npm remove @types/@meronex/icons
```

## Contributing

### Development

```bash
yarn
yarn submodule  # fetch icon sources
cd packages/react-icons
yarn build
```

### Preview
The preview site is the [`meronex-icons`](https://icons.meronex.com) website, built in [NextJS](https://nextjs.org/).

```bash
cd packages/react-icons
yarn build

cd ../preview
yarn start
```

### Demo
The demo is a [Create React App](https://create-react-app.dev/) boilerplate with `react-icons` added as a dependency for easy testing.

```bash
cd packages/react-icons
yarn build

cd ../demo
yarn start
```

### How to add an icon set

#### 1. Add new git submodule

From the main directory (where this file is located) run the following command:

```bash	```bash
cd packages/react-icons	git submodule add --name <name> <git-repo-url-for-the-new-icon-set> packages/react-icons/src/icons/<name>
yarn build	```


cd ../demo	#### 2. Modify **README.md** (this document)
yarn start	
Add the name, URL, and the license link to the table in the `##Icons` section of this file.
Keep the list in alphabetical order.

#### 3. Modify **packages/react-icons/.gitignore**

Add the two-letter folder name for the new icon set, e.g.:

```text
...
/xy/
...
```


#### 4. Modify **packages/react-icons/LICENSE**

Add license details about the new icon set.

#### 5. Modify **packages/react-icons/src/icons/index.js**

Add the object with the following structure:

```JavaScript
{
      id: "xy",                                    // Two-letter id
      name: "e.g. Xenon Yellow Icons",             // The full icon set name
      contents: [
        {
          files: path.resolve(__dirname, "<relative-path-to-git-submodule>/<path-to-svg-icons>/<filter>"),
          formatter: name => `Xy${name}`            // So that all icon names from this set will start with "Xy"
        }
      ],
      // URL of the github repo
      projectUrl: "https://github.com/xy/xy-icons",
      license: "Apache License Version 2.0",        // License type
      licenseUrl: "http://www.apache.org/licenses/" // URL of the license definition
}
```

to the `icons` array.

#### 6. Once everything builds and looks right in the preview, create a pull request

## Why React SVG components instead of fonts?

SVG is [supported by all major browsers](http://caniuse.com/#search=svg). With `react-icons`, you can serve only the needed icons instead of one big font file to the users, helping you to recognize which icons are used in your project.

## Related Projects

- [react-svg-morph](https://github.com/gorangajic/react-svg-morph/)

## Licence

MIT

- Icons are taken from the other projects so please check each project licences accordingly.
# [Meronex Icons](https://icons.meronex.com/) (react-icons fork)

[![npm][npm-image]][npm-url]

[npm-image]: https://img.shields.io/npm/v/react-icons.svg?style=flat-square
[npm-url]: https://www.npmjs.com/package/react-icons

Include popular icons in your React projects easily with `react-icons`, which utilizes ES6 imports that allows you to include only the icons that your project is using.

## Credits & Motivation for the fork

This is a fork of [react-icons](https://github.com/react-icons/react-icons) and was created specifically to resolve issue the bundling issue [#154, see here](https://github.com/react-icons/react-icons/issues/154).

It was meant to be used temporary until the changes are merged upstream however due to the lack of activity in react-icons, I have decided to put it publicly due to the inactivity. 

#### Why did you change the logo/theme of the preview site? 

Again,this was meant for internal consumption, the bundle issue was show stopper for us. I shared it because I thought it might 
help others, I hope those changes gets merged upstream. 

#### What else did you change?

I've merged some open pull requests, added icons and fixed some performance issue with the preview site, more specifically:

- Added Icon Sets
    - flag-icon-css
    - IcoMoon Free
    - Simple Icons
    - Logos
    - VS Code Icons
    - Remix Icons fill
    - Heroicons
    - BoxIcons
    
- Merged open PRs 
    - Remove pId attribute from AI icons [#310](https://github.com/react-icons/react-ic)
    - Add support for stroke-based icons [#284](https://github.com/react-icons/react-icons/pull/284)
    
- Improved Preview Site
    - Show the icon set next to the titles
    - Improve search performance by caching results
    - Copy the entire absolute URL so it can be easily inserted
 
#### Do you plan to keep maintaining it?

I'd rather have the changes merged upstream, but I will keep this maintained if saves others time and effort and the main 
react-icons remains in active. 

   
## Installation

### Yarn
```bash
yarn add @meronex/icons
```

### NPM
```bash
npm install @meronex/icons --save
```

## Usage

```jsx
import  FaBeer from '@meronex/icons/FaBeer';

class Question extends React.Component {
    render() {
        return <h3> Lets go for a <FaBeer />? </h3>
    }
}
```

[View the documentation](https://icons.meronex.com/) for further usage examples and how to use icons from other packages. *NOTE*: each Icon package has it's own subfolder under `@meronex/icons` you import from.

For example, to use an icon from **Material Design**, your import would be: `import  ICON_NAME  from 'react-icons/md/ICON_NAME';`

## Icons

Icon Library|License|Version
---|---|---
[Font Awesome](https://fontawesome.com/)|[CC BY 4.0 License](https://creativecommons.org/licenses/by/4.0/)|5.12.1
[Ionicons](https://ionicons.com/)|[MIT](https://github.com/ionic-team/ionicons/blob/master/LICENSE)|4.5.6
[Material Design icons](http://google.github.io/material-design-icons/)|[Apache License Version 2.0](https://github.com/google/material-design-icons/blob/master/LICENSE)|3.0.1
[Material Design Community icons](https://github.com/templarian/MaterialDesign)|[SIL](https://github.com/google/material-design-icons/blob/master/LICENSE)|52442e9e6ea4424c41fb6489911c6f87fe83a7a8
[Typicons](http://s-ings.com/typicons/)|[CC BY-SA 3.0](https://creativecommons.org/licenses/by-sa/3.0/)|2.0.9
[Github Octicons icons](https://octicons.github.com/)|[MIT](https://github.com/primer/octicons/blob/master/LICENSE)|8.5.0
[Feather](https://feathericons.com/)|[MIT](https://github.com/feathericons/feather/blob/master/LICENSE)|4.21.0
[Game Icons](https://game-icons.net/)|[CC BY 3.0](https://creativecommons.org/licenses/by/3.0/)|a53463d41d4f055fa71097ae74da4c508c9bb09d
[Weather Icons](https://erikflowers.github.io/weather-icons/)|[SIL OFL 1.1](http://scripts.sil.org/OFL)|2.0.10
[Devicons](https://vorillaz.github.io/devicons/)|[MIT](https://opensource.org/licenses/MIT)|1.8.0
[Ant Design Icons](https://github.com/ant-design/ant-design-icons)|[MIT](https://opensource.org/licenses/MIT)|4.0.0
[Bootstrap Icons](https://github.com/twbs/icons)|[MIT](https://opensource.org/licenses/MIT)|1.0.0-alpha3
[Remix Icon](https://github.com/Remix-Design/RemixIcon)|[Apache License Version 2.0](http://www.apache.org/licenses/)|2.3.0
[Flat Color Icons](https://github.com/icons8/flat-color-icons)|[MIT](https://opensource.org/licenses/MIT)|1.0.2
[Grommet-Icons](https://github.com/grommet/grommet-icons)|[Apache License Version 2.0](http://www.apache.org/licenses/)|4.4.0
[css.gg](https://github.com/astrit/css.gg)|[MIT](https://opensource.org/licenses/MIT)|2.0.0
[IcoMoon Free](https://github.com/Keyamoon/IcoMoon-Free)|[CC BY 4.0 License](https://creativecommons.org/licenses/by/4.0/)|1.0.0
[BoxIcons](https://github.com/atisawd/boxicons)|[CC BY 4.0 License](https://creativecommons.org/licenses/by/4.0/)|2.0.5
[VS Code Icons](https://github.com/microsoft/vscode-codicons)|[CC BY 4.0](https://creativecommons.org/licenses/by/4.0/)|0.0.1
[flag-icon-css](https://github.com/lipis/flag-icon-css)|[MIT License](https://github.com/lipis/flag-icon-css/blob/master/LICENSE)|3.5.0
[Logos](https://github.com/gilbarbara/logos)|[CC0 1.0 Universal](https://github.com/gilbarbara/logos/blob/master/LICENSE.txt)|2018.01
[Simple Icons](https://simpleicons.org/)|[CC0 1.0 Universal](https://creativecommons.org/publicdomain/zero/1.0/)| 1.17.1-998-gd4b07ad4
[Heroicons](https://github.com/refactoringui/heroicons)|[MIT](https://opensource.org/licenses/MIT)| v0.3.7

## Configuration

You can configure react-icons props using [React Context API](https://reactjs.org/docs/context.html).

_Requires **React 16.3** or higher._

```jsx
import { IconContext } from "@meronex/icons";

<IconContext.Provider value={{ color: "blue", className: "global-class-name" }}>
  <div>
    <FaFolder />
  </div>
</IconContext.Provider>
```

| Key         | Default               | Notes                           |
| ----------- | --------------------- | ------------------------------- |
| `color`     | `undefined` (inherit) |                                 |
| `size`      | `1em`                 |                                 |
| `className` | `undefined`           |                                 |
| `style`     | `undefined`           | Can overwrite size and color    |
| `attr`      | `undefined`           | Overwritten by other attributes |
| `title`     | `undefined`           | Icon description for accessibility |


### Adjustment CSS

From version 3, `vertical-align: middle` is not automatically given. Please use IconContext to specify className or specify an inline style.

#### Global Inline Styling

```tsx
<IconContext.Provider value={{ style: { verticalAlign: 'middle' } }}>
```

#### Global `className` Styling

Component

```tsx
<IconContext.Provider value={{ className: 'react-icons' }}>
```

CSS

```css
.react-icons {
  vertical-align: middle;
}
```

### TypeScript native support

Dependencies on `@types/@meronex/icons` can be deleted.

#### Yarn
```bash
yarn remove @types/@meronex/icons
```

#### NPM
```bash
npm remove @types/@meronex/icons
```

## Contributing

### Development

```bash
yarn
yarn submodule  # fetch icon sources
cd packages/react-icons
yarn build
```

### Preview
The preview site is the [`meronex-icons`](https://icons.meronex.com) website, built in [NextJS](https://nextjs.org/).

```bash
cd packages/react-icons
yarn build

cd ../preview
yarn start
```

### Demo
The demo is a [Create React App](https://create-react-app.dev/) boilerplate with `react-icons` added as a dependency for easy testing.

```bash
cd packages/react-icons
yarn build

cd ../demo
yarn start
```

### How to add an icon set

#### 1. Add new git submodule

From the main directory (where this file is located) run the following command:

```bash	```bash
cd packages/react-icons	git submodule add --name <name> <git-repo-url-for-the-new-icon-set> packages/react-icons/src/icons/<name>
yarn build	```


cd ../demo	#### 2. Modify **README.md** (this document)
yarn start	
Add the name, URL, and the license link to the table in the `##Icons` section of this file.
Keep the list in alphabetical order.

#### 3. Modify **packages/react-icons/.gitignore**

Add the two-letter folder name for the new icon set, e.g.:

```text
...
/xy/
...
```


#### 4. Modify **packages/react-icons/LICENSE**

Add license details about the new icon set.

#### 5. Modify **packages/react-icons/src/icons/index.js**

Add the object with the following structure:

```JavaScript
{
      id: "xy",                                    // Two-letter id
      name: "e.g. Xenon Yellow Icons",             // The full icon set name
      contents: [
        {
          files: path.resolve(__dirname, "<relative-path-to-git-submodule>/<path-to-svg-icons>/<filter>"),
          formatter: name => `Xy${name}`            // So that all icon names from this set will start with "Xy"
        }
      ],
      // URL of the github repo
      projectUrl: "https://github.com/xy/xy-icons",
      license: "Apache License Version 2.0",        // License type
      licenseUrl: "http://www.apache.org/licenses/" // URL of the license definition
}
```

to the `icons` array.

#### 6. Once everything builds and looks right in the preview, create a pull request

## Why React SVG components instead of fonts?

SVG is [supported by all major browsers](http://caniuse.com/#search=svg). With `react-icons`, you can serve only the needed icons instead of one big font file to the users, helping you to recognize which icons are used in your project.

## Related Projects

- [react-svg-morph](https://github.com/gorangajic/react-svg-morph/)

## Licence

MIT

- Icons are taken from the other projects so please check each project licences accordingly.
